<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/src/bedrock_server_manager/web/static/image/icon/favicon.svg" alt="ICON" width="200" height="200">
</div> 

# Bedrock Server Manager

Bedrock Server Manager is a comprehensive python package designed for installing, managing, and maintaining Minecraft Bedrock Dedicated Servers with ease, and is Linux/Windows compatable.

<img alt="PyPI - Version" src="https://img.shields.io/pypi/v/bedrock-server-manager?link=https%3A%2F%2Fpypi.org%2Fproject%2Fbedrock-server-manager%2F"> <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/bedrock-server-manager"> <img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dw/bedrock-server-manager"> <img alt="License" src="https://img.shields.io/github/license/dmedina559/bedrock-server-manager">

See the brand new [documentation](https://bedrock-server-manager.readthedocs.io/en/latest/) for more information.

Quick links:

- [Changelog](https://bedrock-server-manager.readthedocs.io/en/latest/changelog.html)
- [Installation](https://bedrock-server-manager.readthedocs.io/en/latest/general/introduction.html#prerequisites)
- [CLI Commands](https://bedrock-server-manager.readthedocs.io/en/latest/cli/commands.html)
- [Web Interface](https://bedrock-server-manager.readthedocs.io/en/latest/web/general.html)
- [Plugins](https://bedrock-server-manager.readthedocs.io/en/latest/plugins/introduction.html)

# Project Images

<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/docs/images/cli_menu.png" alt="ICON" width="400" height="200">
</div> 

<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/docs/images/main_index.png" alt="ICON" width="400" height="200">
</div> 

<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/docs/images/cli_manage_server_menu.png" alt="ICON" width="400" height="200">
</div> 

<div style="text-align: center;">
    <img src="https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/docs/images/web_install_addons.png" alt="ICON" width="400" height="200">
</div> 

